Struct protobuf_codegen::Customize [−][src]
pub struct Customize {
pub expose_oneof: Option<bool>,
pub expose_fields: Option<bool>,
pub generate_accessors: Option<bool>,
pub carllerche_bytes_for_bytes: Option<bool>,
pub carllerche_bytes_for_string: Option<bool>,
}Specifies style of generated code.
Fields
expose_oneof: Option<bool>
Make oneof enum public.
expose_fields: Option<bool>
When true all fields are public, and accessors are not generated
generate_accessors: Option<bool>
When false, get_, set_, mut_ etc. accessors are not generated
carllerche_bytes_for_bytes: Option<bool>
Use bytes::Bytes for bytes fields
carllerche_bytes_for_string: Option<bool>
Use bytes::Bytes for string fields
Methods
impl Customize[src]
impl Customizepub fn update_with(&mut self, that: &Customize)[src]
pub fn update_with(&mut self, that: &Customize)Update fields of self with fields defined in other customize
pub fn set_defaults_from(&mut self, other: &Customize)[src]
pub fn set_defaults_from(&mut self, other: &Customize)Update unset fields of self with fields from other customize